@@ -4,7 +4,7 @@
 # Like what you see? Join us!
 # https://www.univention.com/about-us/careers/vacancies/
 #
-# SPDX-FileCopyrightText: 2024 Univention GmbH
+# SPDX-FileCopyrightText: 2024-2025 Univention GmbH
 # SPDX-License-Identifier: AGPL-3.0-only
 
 import builtins
@@ -63,7 +63,7 @@ def ucr(monkeypatch, tmpdir):
     return extra
 
 
-@pytest.fixture()
+@pytest.fixture
 def http(mocker):
     """Mock HTTP requests via py3:urllib.requests"""
     ressources = {}
@@ -155,7 +155,7 @@ class MockPopen:
         cls.mock_stdout = cls.mock_stderr = b''
 
 
-@pytest.fixture()
+@pytest.fixture
 def mockpopen(monkeypatch):
     """Mock :py:meth:`subprocess.Popen()` usage"""
     monkeypatch.setattr(subprocess, 'Popen', MockPopen)
@@ -229,7 +229,7 @@ class MockFileManager:
         self.files[name] = ex
 
 
-@pytest.fixture()
+@pytest.fixture
 def mockopen(monkeypatch, tmpdir):
     """Mock :py:func:`open()` usage"""
     manager = MockFileManager(tmpdir)
