@@ -2,32 +2,8 @@
 # Like what you see? Join us!
 # https://www.univention.com/about-us/careers/vacancies/
 #
-# Copyright 2008-2025 Univention GmbH
-#
-# https://www.univention.de/
-#
-# All rights reserved.
-#
-# The source code of this program is made available
-# under the terms of the GNU Affero General Public License version 3
-# (GNU AGPL V3) as published by the Free Software Foundation.
-#
-# Binary versions of this program provided by Univention to you as
-# well as other copyrighted, protected or trademarked materials like
-# Logos, graphics, fonts, specific documentations and configurations,
-# cryptographic keys etc. are subject to a license agreement between
-# you and Univention and not subject to the GNU AGPL V3.
-#
-# In the case you use this program under the terms of the GNU AGPL V3,
-# the program is provided in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-# GNU Affero General Public License for more details.
-#
-# You should have received a copy of the GNU Affero General Public
-# License with the Debian GNU/Linux or Univention distribution in file
-# /usr/share/common-licenses/AGPL-3; if not, see
-# <https://www.gnu.org/licenses/>.
+# SPDX-FileCopyrightText: 2008-2025 Univention GmbH
+# SPDX-License-Identifier: AGPL-3.0-only
 """Univention Update tools."""
 
 from __future__ import annotations
@@ -584,6 +560,25 @@ class UCSHttpServer(_UCSServer):
             UCSHttpServer.password_manager.add_password(realm=None, uri=uri, user=self.baseurl.username, passwd=self.baseurl.password)
         req = urllib.request.Request(uri)  # noqa: S310
 
+        # Add preemptive authentication for JFrog Artifactory compatibility
+        has_credentials = False
+        # Try to get credentials from password manager first
+        username_pm, password_pm = UCSHttpServer.password_manager.find_user_password(None, uri)
+
+        credentials_to_use = None
+        if username_pm and password_pm:
+            credentials_to_use = f"{username_pm}:{password_pm}"
+            self.log.debug('Using credentials from password manager for %s', uri)
+        elif self.baseurl.username and self.baseurl.password:
+            credentials_to_use = f"{self.baseurl.username}:{self.baseurl.password}"
+            self.log.debug('Using credentials from baseurl for %s', uri)
+
+        if credentials_to_use:
+            has_credentials = True
+            # Use ISO8859-1 encoding as per HTTP Basic Auth standard
+            encoded_creds = base64.b64encode(credentials_to_use.encode('ISO8859-1')).decode('ASCII')
+            req.add_header("Authorization", f"Basic {encoded_creds}")
+
         def get_host() -> str:
             return req.host
 
@@ -642,6 +637,10 @@ class UCSHttpServer(_UCSServer):
             self.log.debug("Failed %s %s: %s", req.get_method(), req.get_full_url(), res, exc_info=True)
             if res.code == httplib.UNAUTHORIZED:  # 401
                 raise ConfigurationError(uri, 'credentials not accepted')
+            if res.code == httplib.FORBIDDEN:  # 403
+                # JFrog Artifactory may return 403 instead of 401 for authentication failures
+                if has_credentials:
+                    raise ConfigurationError(uri, 'authentication failed (forbidden)')
             if res.code == httplib.PROXY_AUTHENTICATION_REQUIRED:  # 407
                 raise ProxyError(uri, 'credentials not accepted')
             if res.code in (httplib.BAD_GATEWAY, httplib.GATEWAY_TIMEOUT):  # 502 504
@@ -1115,7 +1114,7 @@ class Component:
 
     @property
     def _parts(self) -> list[str]:
-        parts = ["maintained"] + ["unmaintained"][:self.updater.configRegistry.is_true(self.ucrv('unmaintained'))]
+        parts = ["maintained", *["unmaintained"][:self.updater.configRegistry.is_true(self.ucrv('unmaintained'))]]
         return ['%s/component' % (part,) for part in parts]
 
 
